---
title: <span class="badge object-type-scalar"></span> Terabytes
---
# <span class="badge object-type-scalar"></span> Terabytes

Data: terabytes

## Definition

```python
# Data: terabytes
Terabytes: typing.Literal["dectbytes"] = "dectbytes"
```
